@@ -10,10 +10,10 @@ pub mod error;
 pub mod fast_log;
 pub mod filter;
 pub mod plugin;
-pub mod wait;
 pub mod runtime;
 pub mod config;
 
 pub use fast_log::*;
 pub use runtime::*;
+pub use crate::config::Config;
 
